@@ -379,6 +379,20 @@ def get_parser(prog_name):
         default=None,
         help="control model used for translation, see API for information",
     )
+    parser_text.add_argument(
+        "--style-id",
+        dest="style_rule",
+        type=str,
+        help="ID of style rule to use for translation",
+    )
+    parser_text.add_argument(
+        "--custom-instructions",
+        dest="custom_instructions",
+        action="append",
+        type=str,
+        help="custom instructions to guide translation (can be specified "
+        "multiple times, max 10 instructions, each max 300 characters)",
+    )
     parser_text.add_argument(
         "text",
         nargs="+",
@@ -408,6 +422,13 @@ def get_parser(prog_name):
         default=None,
         help="activate processing of formatting tags, for example 'xml'",
     )
+    tag_handling_group.add_argument(
+        "--tag-handling-version",
+        type=str,
+        choices=["v1", "v2"],
+        default=None,
+        help="specify which version of the tag handling algorithm to use",
+    )
     tag_handling_group.add_argument(
         "--outline-detection-off",
         dest="outline_detection",
